require 'spec_helper'

module Wizypay
  RSpec.describe BalanceReport do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let!(:request) { stub_request(:get, "#{api_endpoint}/balance_report?granularity=month").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }).
        to_return(status: 200, body: '{"data": [{"date": "2016-02-01"}]}') }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    describe '.show' do
      it 'returns' do
        response = BalanceReport.show('month')
        expect(request).to have_been_made
        expect(response.length).to eq 1
        expect(response.first).to be_a(BalanceReport::Line)
        expect(response.first.date).to be_a(Date)
      end
    end

    describe '.monthly' do
      it 'delegates to show' do
        expect(BalanceReport).to receive(:show).with('month', {})
        BalanceReport.monthly
      end
    end

    describe '.daily' do
      it 'delegates to show' do
        expect(BalanceReport).to receive(:show).with('day', {})
        BalanceReport.daily
      end
    end
  end
end
