require 'spec_helper'

module Wizypay
  RSpec.describe Beneficiary do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:id) { 3 }
    let(:kyc_compliant) { false }
    let(:all_beneficiaries_request) { stub_request(:get, "#{api_endpoint}/beneficiaries").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    let(:where_beneficiaries_request) { stub_request(:get, "#{api_endpoint}/beneficiaries?first_name=john").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    let(:beneficiary_request) { stub_request(:get, "#{api_endpoint}/beneficiaries/#{id}").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    let(:update_request) { stub_request(:put, "#{api_endpoint}/beneficiaries/#{id}").
        with(body:    { 'id' => id.to_s, 'kyc_compliant' => kyc_compliant.to_s },
             headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    context 'all' do
      it 'is a collection' do
        all_beneficiaries_request.to_return(status: 200, body: '{"data":[{"id":3,"client_name":"Dummy","email":"joel@wizypay.com","last_name":"Cogen","first_name":"Joel","recent_amount":1337}],"meta":{"total_pages":1,"current_page":1,"limit_value":25}}')
        response = Beneficiary.all
        expect(response).to be_a(Collection)
        expect(response.first).to be_a(Beneficiary)
        expect(response.first.first_name).to eq 'Joel'
      end
    end

    context 'where' do
      it 'returns empty body' do
        request  = where_beneficiaries_request.to_return(status: 200, body: '{"data": []}')
        response = Beneficiary.where(first_name: 'john')
        expect(request).to have_been_made
        expect(response).to be_empty
      end
    end

    context 'find' do
      it 'returns' do
        request  = beneficiary_request.to_return(status: 200, body: '{"data":{"id":3,"client_name":"Dummy","email":"joel@wizypay.com","name":"Joel Cogen","recent_amount":1337,"phone":null,"kyc_compliant?":true,"cards":{"data":[{"created_at":"2016-02-01T15:03:43.015+01:00","amount":1337,"status":"cancelled","merchant_ref":91,"partial_number":"XXXX-8674","real_merchant_ref":null,"user":{"id":1,"email":"joel@wizypay.com","last_name":"Cogen","first_name":"Joel"}}]}}}')
        response = Beneficiary.find(id)
        expect(request).to have_been_made
        expect(response).to be_a(Beneficiary)
        expect(response.name).to eq 'Joel Cogen'
        expect(response.cards).to be_a(Collection)
        expect(response.cards.first).to be_a(DebitCard)
      end
    end

    context 'save' do
      it 'puts' do
        request  = update_request.to_return(status: 200, body: '{"data":{"id":3,"client_name":"Dummy","email":"joel@wizypay.com","name":"Joel Cogen","recent_amount":1337,"phone":null,"kyc_compliant?":false,"cards":{"data":[{"created_at":"2016-02-01T15:03:43.015+01:00","amount":1337,"status":"cancelled","merchant_ref":91,"partial_number":"XXXX-8674","real_merchant_ref":null,"user":{"id":1,"email":"joel@wizypay.com","last_name":"Cogen","first_name":"Joel"}}]}}}')
        beneficiary = Beneficiary.new(id: id, kyc_compliant: kyc_compliant)
        beneficiary.save
        expect(request).to have_been_made
        expect(beneficiary.name).to eq 'Joel Cogen'
        expect(beneficiary.kyc_compliant?).to eq kyc_compliant
      end
    end
  end
end
