require 'spec_helper'

module Wizypay
  RSpec.describe DebitCard do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:card_id) { 1 }
    let(:card_request) { stub_request(:get, "#{api_endpoint}/debit_cards/#{card_id}").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    it 'is a card' do
      request  = card_request.to_return(status: 200, body: '{"data": {"id": 1, "partial_number": "XXXX-1234"}}')
      response = DebitCard.find(card_id)
      expect(request).to have_been_made
      expect(response).to be_a(DebitCard)
      expect(response.partial_number).to eq 'XXXX-1234'
    end

    it 'has operations' do
      card_request.to_return(status: 200, body: '{"data": {"operations": {"data": [{"id": 1}]}}}')
      response = DebitCard.find(card_id)
      expect(response.operations).to be_a(Collection)
      expect(response.operations.first).to be_a(VdcOperation)
      expect(response.operations.first.id).to eq 1
    end

    it 'has refunds' do
      card_request.to_return(status: 200, body: '{"data": {"refunds": {"data": [{"id": 1}]}}}')
      response = DebitCard.find(card_id)
      expect(response.refunds).to be_a(Collection)
      expect(response.refunds.first).to be_a(Refund)
      expect(response.refunds.first.id).to eq 1
    end
  end
end
