require 'spec_helper'

module Wizypay
  RSpec.describe 'DebitCard#refund' do

    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:reference) { '85fb584c-72cb-4f35-b307-ac5442ef7153' }
    let(:amount) { 2000 }
    let(:refund_request) { stub_request(:post, "#{api_endpoint}/debit_cards/#{reference}/refund").
        with(body:    { 'amount'        => amount.to_s },
             headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/,
                        'Content-Type'  => 'application/x-www-form-urlencoded' }) }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    context 'success' do
      it 'returns empty body' do
        request  = refund_request.to_return(status: 200, body: '')
        response = DebitCard.new(reference: reference).refund(amount)
        expect(request).to have_been_made
        expect(response).to be_empty
      end
    end

    describe '.refund' do
      it 'delegates to an instance' do
        expect(DebitCard).to receive(:new).with(reference: reference).and_return(card = double('card'))
        expect(card).to receive(:refund).with(amount)
        DebitCard.refund(reference, amount)
      end
    end
  end
end
