require 'spec_helper'

module Wizypay
  RSpec.describe GiftCard do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:all_cards_request) { stub_request(:get, "#{api_endpoint}/gift_cards").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    let(:where_cards_request) { stub_request(:get, "#{api_endpoint}/gift_cards?beneficiary=john").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }) }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    context 'all' do
      it 'returns empty body' do
        request  = all_cards_request.to_return(status: 200, body: '{"data": []}')
        response = GiftCard.all
        expect(request).to have_been_made
        expect(response).to be_empty
      end

      it 'is a collection' do
        all_cards_request.to_return(status: 200, body: '{"data": [{"id": 1, "partial_number": "XXXX-1234"}]}')
        response = GiftCard.all
        expect(response).to be_a(Collection)
        expect(response.first).to be_a(GiftCard)
        expect(response.first.partial_number).to eq 'XXXX-1234'
      end
    end

    context 'where' do
      it 'returns empty body' do
        request  = where_cards_request.to_return(status: 200, body: '{"data": []}')
        response = GiftCard.where(beneficiary: 'john')
        expect(request).to have_been_made
        expect(response).to be_empty
      end
    end
  end
end
