require 'spec_helper'
require 'time'

module Wizypay
  RSpec.describe 'GiftCard#url' do
    include SimpleHmac::Helper

    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:reference) { '85fb584c-72cb-4f35-b307-ac5442ef7153' }

    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    it 'returns' do
      t = Time.new(2015, 1, 1, 0, 0, 0, "+01:00")
      Timecop.freeze(t) do
        url = GiftCard.new(reference: reference).url
        expected_security = sign_string("#{reference}\n#{t.httpdate}", api_secret)
        expect(url).to eq("#{api_endpoint}/widget?key=#{URI::encode_www_form_component api_key}"+
                              "&timestamp=#{URI::encode_www_form_component t.httpdate}" +
                              "&reference=#{URI::encode_www_form_component reference}"+
                              "&security=#{URI::encode_www_form_component expected_security}")
      end
    end

    describe '.url' do
      it 'delegates to an instance' do
        expect(GiftCard).to receive(:new).with(reference: reference).and_return(card = double('card'))
        expect(card).to receive(:url)
        GiftCard.url(reference)
      end
    end
  end
end
