require 'spec_helper'

module Wizypay
  RSpec.describe 'GiftCard.create' do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:user) { { id: 33, first_name: 'Nicolas', last_name: 'Cage' } }
    let(:reference) { '85fb584c-72cb-4f35-b307-ac5442ef7153' }
    let(:merchant_id) { '91' }
    let(:amount) { '5000' }
    let(:currency) { 'EUR' }
    let(:create_request) { stub_request(:post, "#{api_endpoint}/gift_cards").
        with(body:    { amount:    amount, currency: currency, merchant_id: merchant_id,
                        reference: reference, user: user.to_json },
             headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/,
                        'Content-Type'  => 'application/x-www-form-urlencoded' }) }
    let!(:cancel_request) { stub_request(:post, "#{api_endpoint}/gift_cards/#{reference}/cancel").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/,
                        'Content-Type'  => 'application/x-www-form-urlencoded' }) }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    context 'success' do
      it 'returns a Card with correct data' do
        response_body = {
            reference:   reference,
            type:        'Mastercard',
            amount:      amount,
            currency:    currency,
            merchant_id: merchant_id,
            user_id:     user[:id]
        }
        request       = create_request.to_return(status: 200, body: response_body.to_json)
        response      = GiftCard.create(reference, amount, currency, merchant_id, user)
        expect(request).to have_been_made
        expect(response).to be_a(GiftCard)
        expect(response.to_h).to match(response_body)
      end
    end

    context 'failure' do
      context '4XX' do
        it "throws #{RestClient::Exception}" do
          request = create_request.to_return(status: 401, body: { errors: { base: ['authentication_failed'] } }.to_json)
          expect do
            GiftCard.create(reference, amount, currency, merchant_id, user)
          end.to raise_error(RestClient::Exception)
          expect(request).to have_been_made
          expect(cancel_request).to have_been_made
        end
      end

      context 'timeout' do
        it "throws #{RestClient::Exception}" do
          request = create_request.to_timeout
          expect do
            GiftCard.create(reference, amount, currency, merchant_id, user)
          end.to raise_error(RestClient::Exception)
          expect(request).to have_been_made
          expect(cancel_request).to have_been_made
        end
      end
    end
  end
end
