require 'spec_helper'

module Wizypay
  RSpec.describe MerchantVersion do
    let(:api_key) { 'key' }
    let(:api_secret) { 'secret' }
    let(:api_endpoint) { 'https://api.wizypay.com' }
    let(:merchant_id) { 91 }
    let!(:request) { stub_request(:get, "#{api_endpoint}/merchants/#{merchant_id}/versions").
        with(headers: { 'Accept'        => 'application/json',
                        'Authorization' => /WIZYPAY #{api_key}:.*/ }).
        to_return(status: 200, body: '{"data": [{"merchant": {"data": {"name": "old name"}}}]}') }
    before do
      Wizypay.setup(api_key, api_secret, api_endpoint)
    end

    describe '.for' do
      it 'returns' do
        response = MerchantVersion.for(Merchant.new(id: merchant_id))
        expect(request).to have_been_made
        expect(response.length).to eq 1
        expect(response.first).to be_a(MerchantVersion)
        expect(response.first.merchant).to be_a(Merchant)
        expect(response.first.merchant.name).to eq 'old name'
      end
    end

    describe '.for_id' do
      it 'returns' do
        response = MerchantVersion.for_id(merchant_id)
        expect(request).to have_been_made
        expect(response.length).to eq 1
        expect(response.first).to be_a(MerchantVersion)
        expect(response.first.merchant).to be_a(Merchant)
        expect(response.first.merchant.name).to eq 'old name'
      end
    end

    describe 'Merchant#versions' do
      it 'returns' do
        response = Merchant.new(id: merchant_id).versions
        expect(request).to have_been_made
        expect(response.length).to eq 1
        expect(response.first).to be_a(MerchantVersion)
        expect(response.first.merchant).to be_a(Merchant)
        expect(response.first.merchant.name).to eq 'old name'
      end
    end
  end
end
